@@ -1,5 +1,5 @@
 package Class::groups ;
-$VERSION = 1.61 ;
+$VERSION = 1.62 ;
 
 ; use 5.006_001
 ; use base 'Class::props'
@@ -11,7 +11,9 @@ $VERSION = 1.61 ;
    { my ( $pkg, @args ) = @_
    ; my $callpkg = caller
    ; foreach my $group ( @args )
-      { $$group{name} = [ $$group{name} ]
+      { $group = { name => $group }
+                 unless ref $group eq 'HASH'
+      ; $$group{name} = [ $$group{name} ]
                         unless ref $$group{name} eq 'ARRAY'
       ; foreach my $n ( @{$$group{name}} )
          { if (  not($$group{no_strict})
@@ -105,9 +107,9 @@ __END__
 
 Class::groups - Pragma to implement group of properties
 
-=head1 VERSION 1.61
+=head1 VERSION 1.62
 
-Included in OOTools 1.61 distribution.
+Included in OOTools 1.62 distribution.
 
 The latest versions changes are reported in the F<Changes> file in this distribution.
 
@@ -167,6 +169,9 @@ From the directory where this file is located, type:
     package MyClass ;
     
     # implement group method without options
+    use Class::groups qw(this that) ;
+
+    # implement group method with properties
     use Class::groups { name  => 'myGroup' ,
                         props => [qw(prop1 prop2)]
                       } ;
@@ -292,7 +297,7 @@ The original <@_> is passed to the referenced pre_process CODE. Modify C<@_> in
 
 =head2 default
 
-Use this option to set a I<default value>. The I<default value> must be a HASH reference or a CODE reference. If it is a Code reference it will be evaluated at runtime and the property will be set to the HASH reference that the referenced CODE must return.
+Use this option to set a I<default value>. The I<default value> must be a HASH reference or a CODE reference. If it is a CODE reference it will be evaluated at runtime and the property will be set to the HASH reference that the referenced CODE must return.
 
 You can reset a property to its default value by assigning an empty HASH reference ({}) to it.
 
